@@ -12,6 +12,9 @@ This file only deals with non-GUI configuration features
 sip API incompatibility issue in spyder's non-gui modules)
 """
 
+from __future__ import annotations
+
+from collections.abc import Callable
 from glob import glob
 import locale
 import os
@@ -87,6 +90,11 @@ def running_in_binder():
     )
 
 
+def building_autodoc():
+    """Return True if executing under Sphinx Autodoc, False otherwise."""
+    return bool(os.environ.get('SPHINX_AUTODOC'))
+
+
 def is_stable_version(version):
     """
     Return true if version is stable, i.e. with letters in the final component.
@@ -435,7 +443,7 @@ def get_interface_language():
     2.) Spyder provides ('en', 'de', 'fr', 'es' 'hu' and 'pt_BR'), if the
     locale is either 'pt' or 'pt_BR', this function will return 'pt_BR'
     """
-    
+
     if os.name == "nt":
         # Changing to locale.getlocale from locale.getdefaultlocale caused some
         # Windows machines to return non BCP47 locale codes. Instead use
@@ -508,27 +516,64 @@ def load_lang_conf():
     return lang
 
 
-def get_translation(modname, dirname=None):
-    """Return translation callback for module *modname*"""
+def get_translation(
+    modname: str, dirname: str | None = None
+) -> Callable[[str], str]:
+    """
+    Return the translation callback for module ``modname``.
+
+    Parameters
+    ----------
+    modname : str
+        The module to get the translation callback for.
+    dirname : str | None, optional
+        The directory name of the module, same as the module name by default.
+
+    Returns
+    -------
+    Callable[[str], str]
+        The gettext translation callback for the given module.
+    """
     if dirname is None:
         dirname = modname
 
-    def translate_dumb(x):
+    def translate_dumb(x: str) -> str:
         """Dumb function to not use translations."""
         return x
 
-    locale_path = get_module_data_path(dirname, relpath="locale",
-                                       attr_name='LOCALEPATH')
+    if building_autodoc():
+
+        def translate_gettext(x: str) -> str:
+            """
+            Translate a text string to the current language for a module.
+
+            Parameters
+            ----------
+            x : str
+                The string to translate.
+
+            Returns
+            -------
+            str
+                The translated string.
+            """
+            return x
+
+        return translate_gettext
+
+    locale_path = get_module_data_path(
+        dirname, relpath="locale", attr_name="LOCALEPATH"
+    )
 
     # If LANG is defined in Ubuntu, a warning message is displayed,
     # so in Unix systems we define the LANGUAGE variable.
     language = load_lang_conf()
-    if os.name == 'nt':
+    if os.name == "nt":
         # Trying to set LANG on Windows can fail when Spyder is
         # run with admin privileges.
         # Fixes spyder-ide/spyder#6886.
         try:
-            os.environ["LANG"] = language      # Works on Windows
+            os.environ["LANG"] = language  # Works on Windows
         except Exception:
             return translate_dumb
     else:
@@ -538,18 +583,33 @@ def get_translation(modname, dirname=None):
         return translate_dumb
 
     import gettext
+
     try:
         _trans = gettext.translation(modname, locale_path)
 
-        def translate_gettext(x):
+        def translate_gettext(x: str) -> str:
+            """
+            Translate a text string to the current language for a module.
+
+            Parameters
+            ----------
+            x : str
+                The string to translate.
+
+            Returns
+            -------
+            str
+                The translated string.
+            """
             return _trans.gettext(x)
+
         return translate_gettext
     except Exception as exc:
         # logging module is not yet initialised at this point
         print(
             f"Could not load translations for {language} due to: "
             f"{exc.__class__.__name__} - {exc}",
-            file=sys.stderr
+            file=sys.stderr,
         )
         return translate_dumb
 
@@ -577,7 +637,7 @@ EXCLUDED_NAMES = ['nan', 'inf', 'infty', 'little_endian', 'colorbar_doc',
 def is_conda_based_app(pyexec=sys.executable):
     """
     Check if Spyder is running from the conda-based installer by looking for
-    the `spyder-menu.json` file.
+    the `conda_based_app` file.
 
     If a Python executable is provided, checks if it is in a conda-based
     installer environment or the root environment thereof.
@@ -598,6 +658,20 @@ def is_conda_based_app(pyexec=sys.executable):
         return False
 
 
+def is_installed_all_users():
+    """
+    Check if conda-based installer is installed for all users.
+    Only for conda-based installers.
+    """
+    real_pyexec = osp.realpath(sys.executable)  # may be symlink
+
+    if not is_conda_based_app(real_pyexec):
+        return False
+
+    root = real_pyexec.split("envs")[0]
+    return not osp.exists(root + ".nonadmin")
+
+
 #==============================================================================
 # Reset config files
 #==============================================================================
